package user

import (
	"duoduo/models/mysql"
	"duoduo/models/user"
	"duoduo/tools/app"

	"github.com/shopspring/decimal"

	"github.com/gin-gonic/gin"
)

func AdminOrderAmount(c *gin.Context) {
	var inData user.AdminOrderAmountRequest
	var outData user.AdminOrderAmountResponse
	var user mysql.User
	var order mysql.Order
	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	userNum, err := user.GetTotal()
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}
	orderNum, err := order.GetTotal()
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	amount, err := order.GetAdminAmount()
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}

	outData.PlatformAmount, err = order.GetPlatform()
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}
	outData.AdminAmount = decimal.NewFromInt(amount)
	outData.AdminAmount = outData.AdminAmount.Mul(decimal.NewFromFloat(0.0015)).Round(2)

	outData.OrderNum = orderNum
	outData.UserNum = userNum

	app.OK(c, outData, app.Success)

}
